"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault")["default"];

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _extends6 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _theme = require("../../theme");

var _group = _interopRequireDefault(require("./group"));

// ============================== Shared ==============================
var genSharedButtonStyle = function genSharedButtonStyle(token) {
  var _componentCls;

  var componentCls = token.componentCls,
      iconCls = token.iconCls;
  return (0, _defineProperty2["default"])({}, componentCls, (_componentCls = {
    outline: 'none',
    position: 'relative',
    display: 'inline-block',
    fontWeight: 400,
    whiteSpace: 'nowrap',
    textAlign: 'center',
    backgroundImage: 'none',
    backgroundColor: 'transparent',
    border: "".concat(token.controlLineWidth, "px ").concat(token.controlLineType, " transparent"),
    cursor: 'pointer',
    transition: "all ".concat(token.motionDurationSlow, " ").concat(token.motionEaseInOut),
    userSelect: 'none',
    touchAction: 'manipulation',
    lineHeight: token.lineHeight,
    color: token.colorText,
    '> span': {
      display: 'inline-block'
    }
  }, (0, _defineProperty2["default"])(_componentCls, "> ".concat(iconCls, " + span, > span + ").concat(iconCls), {
    marginInlineStart: token.marginXS
  }), (0, _defineProperty2["default"])(_componentCls, "&".concat(componentCls, "-block"), {
    width: '100%'
  }), _componentCls));
};

var genHoverActiveButtonStyle = function genHoverActiveButtonStyle(hoverStyle, activeStyle) {
  return {
    '&:not(:disabled)': {
      '&:hover, &:focus': hoverStyle,
      '&:active': activeStyle
    }
  };
}; // ============================== Shape ===============================


var genCircleButtonStyle = function genCircleButtonStyle(token) {
  return {
    minWidth: token.controlHeight,
    paddingInlineStart: 0,
    paddingInlineEnd: 0,
    borderRadius: '50%'
  };
};

var genRoundButtonStyle = function genRoundButtonStyle(token) {
  return {
    borderRadius: token.controlHeight,
    paddingInlineStart: token.controlHeight / 2,
    paddingInlineEnd: token.controlHeight / 2,
    width: 'auto'
  };
}; // =============================== Type ===============================


var genGhostButtonStyle = function genGhostButtonStyle(btnCls, textColor, borderColor, textColorDisabled, borderColorDisabled) {
  return (0, _defineProperty2["default"])({}, "&".concat(btnCls, "-background-ghost"), {
    color: textColor || undefined,
    backgroundColor: 'transparent',
    borderColor: borderColor || undefined,
    boxShadow: 'none',
    '&:hover': {
      backgroundColor: 'transparent'
    },
    '&:disabled': {
      cursor: 'not-allowed',
      color: textColorDisabled || undefined,
      borderColor: borderColorDisabled || undefined
    }
  });
};

var genSolidDisabledButtonStyle = function genSolidDisabledButtonStyle(token) {
  return {
    '&:disabled': {
      cursor: 'not-allowed',
      borderColor: token.colorBorder,
      color: token.colorTextDisabled,
      backgroundColor: token.colorBgContainerDisabled,
      boxShadow: 'none'
    }
  };
};

var genSolidButtonStyle = function genSolidButtonStyle(token) {
  return (0, _extends6["default"])({
    borderRadius: token.controlRadius
  }, genSolidDisabledButtonStyle(token));
};

var genPureDisabledButtonStyle = function genPureDisabledButtonStyle(token) {
  return {
    '&:disabled': {
      cursor: 'not-allowed',
      color: token.colorTextDisabled
    }
  };
}; // Type: Default


var genDefaultButtonStyle = function genDefaultButtonStyle(token) {
  return (0, _extends6["default"])((0, _extends6["default"])((0, _extends6["default"])((0, _extends6["default"])((0, _extends6["default"])({}, genSolidButtonStyle(token)), {
    backgroundColor: token.colorBgContainer,
    borderColor: token.colorBorder,
    boxShadow: "0 ".concat(token.controlOutlineWidth, "px 0 ").concat(token.controlTmpOutline)
  }), genHoverActiveButtonStyle({
    color: token.colorPrimaryHover,
    borderColor: token.colorPrimaryHover
  }, {
    color: token.colorPrimaryActive,
    borderColor: token.colorPrimaryActive
  })), genGhostButtonStyle(token.componentCls, token.colorBgContainer, token.colorBgContainer, token.colorTextDisabled, token.colorBorder)), (0, _defineProperty2["default"])({}, "&".concat(token.componentCls, "-dangerous"), (0, _extends6["default"])((0, _extends6["default"])((0, _extends6["default"])({
    color: token.colorError,
    borderColor: token.colorError
  }, genHoverActiveButtonStyle({
    color: token.colorErrorHover,
    borderColor: token.colorErrorHover
  }, {
    color: token.colorErrorActive,
    borderColor: token.colorErrorActive
  })), genGhostButtonStyle(token.componentCls, token.colorError, token.colorError, token.colorTextDisabled, token.colorBorder)), genSolidDisabledButtonStyle(token))));
}; // Type: Primary


var genPrimaryButtonStyle = function genPrimaryButtonStyle(token) {
  return (0, _extends6["default"])((0, _extends6["default"])((0, _extends6["default"])((0, _extends6["default"])((0, _extends6["default"])({}, genSolidButtonStyle(token)), {
    color: '#FFF',
    backgroundColor: token.colorPrimary,
    boxShadow: "0 ".concat(token.controlOutlineWidth, "px 0 ").concat(token.colorPrimaryOutline)
  }), genHoverActiveButtonStyle({
    backgroundColor: token.colorPrimaryHover
  }, {
    backgroundColor: token.colorPrimaryActive
  })), genGhostButtonStyle(token.componentCls, token.colorPrimary, token.colorPrimary, token.colorTextDisabled, token.colorBorder)), (0, _defineProperty2["default"])({}, "&".concat(token.componentCls, "-dangerous"), (0, _extends6["default"])((0, _extends6["default"])((0, _extends6["default"])({
    backgroundColor: token.colorError,
    boxShadow: "0 ".concat(token.controlOutlineWidth, "px 0 ").concat(token.colorErrorOutline)
  }, genHoverActiveButtonStyle({
    backgroundColor: token.colorErrorHover
  }, {
    backgroundColor: token.colorErrorActive
  })), genGhostButtonStyle(token.componentCls, token.colorError, token.colorError, token.colorTextDisabled, token.colorBorder)), genSolidDisabledButtonStyle(token))));
}; // Type: Dashed


var genDashedButtonStyle = function genDashedButtonStyle(token) {
  return (0, _extends6["default"])((0, _extends6["default"])({}, genDefaultButtonStyle(token)), {
    borderStyle: 'dashed'
  });
}; // Type: Link


var genLinkButtonStyle = function genLinkButtonStyle(token) {
  return (0, _extends6["default"])((0, _extends6["default"])((0, _extends6["default"])({
    color: token.colorLink
  }, genHoverActiveButtonStyle({
    color: token.colorLinkHover
  }, {
    color: token.colorLinkActive
  })), genPureDisabledButtonStyle(token)), (0, _defineProperty2["default"])({}, "&".concat(token.componentCls, "-dangerous"), (0, _extends6["default"])((0, _extends6["default"])({
    color: token.colorError
  }, genHoverActiveButtonStyle({
    color: token.colorErrorHover
  }, {
    color: token.colorErrorActive
  })), genPureDisabledButtonStyle(token))));
}; // Type: Text


var genTextButtonStyle = function genTextButtonStyle(token) {
  return (0, _extends6["default"])((0, _extends6["default"])((0, _extends6["default"])({
    borderRadius: token.controlRadius
  }, genHoverActiveButtonStyle({
    backgroundColor: token.colorBgTextHover
  }, {
    backgroundColor: token.colorBgTextActive
  })), genPureDisabledButtonStyle(token)), (0, _defineProperty2["default"])({}, "&".concat(token.componentCls, "-dangerous"), (0, _extends6["default"])({
    color: token.colorError
  }, genPureDisabledButtonStyle(token))));
};

var genTypeButtonStyle = function genTypeButtonStyle(token) {
  var _ref3;

  var componentCls = token.componentCls;
  return _ref3 = {}, (0, _defineProperty2["default"])(_ref3, "".concat(componentCls, "-default"), genDefaultButtonStyle(token)), (0, _defineProperty2["default"])(_ref3, "".concat(componentCls, "-primary"), genPrimaryButtonStyle(token)), (0, _defineProperty2["default"])(_ref3, "".concat(componentCls, "-dashed"), genDashedButtonStyle(token)), (0, _defineProperty2["default"])(_ref3, "".concat(componentCls, "-link"), genLinkButtonStyle(token)), (0, _defineProperty2["default"])(_ref3, "".concat(componentCls, "-text"), genTextButtonStyle(token)), _ref3;
}; // =============================== Size ===============================


var genSizeButtonStyle = function genSizeButtonStyle(token) {
  var _$concat$concat;

  var sizePrefixCls = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '';
  var componentCls = token.componentCls,
      iconCls = token.iconCls;
  var paddingVertical = Math.max(0, (token.controlHeight - token.fontSize * token.lineHeight) / 2 - token.controlLineWidth);
  var paddingHorizontal = token.padding - token.controlLineWidth;
  var iconOnlyCls = "".concat(componentCls, "-icon-only");
  return [// Size
  (0, _defineProperty2["default"])({}, "".concat(componentCls).concat(sizePrefixCls), (_$concat$concat = {
    fontSize: token.fontSize,
    height: token.controlHeight,
    padding: "".concat(paddingVertical, "px ").concat(paddingHorizontal, "px")
  }, (0, _defineProperty2["default"])(_$concat$concat, "&".concat(iconOnlyCls), {
    width: token.controlHeight,
    paddingInlineStart: 0,
    paddingInlineEnd: 0,
    '> span': {
      transform: 'scale(1.143)' // 14px -> 16px

    }
  }), (0, _defineProperty2["default"])(_$concat$concat, "&".concat(componentCls, "-loading"), {
    opacity: token.opacityLoading,
    cursor: 'default'
  }), (0, _defineProperty2["default"])(_$concat$concat, "".concat(componentCls, "-loading-icon"), {
    transition: "width ".concat(token.motionDurationSlow, " ").concat(token.motionEaseInOut, ", opacity ").concat(token.motionDurationSlow, " ").concat(token.motionEaseInOut)
  }), (0, _defineProperty2["default"])(_$concat$concat, "&:not(".concat(iconOnlyCls, ") ").concat(componentCls, "-loading-icon > ").concat(iconCls), {
    marginInlineEnd: token.marginXS
  }), _$concat$concat)), // Shape - patch prefixCls again to override solid border radius style
  (0, _defineProperty2["default"])({}, "".concat(componentCls).concat(componentCls, "-circle").concat(sizePrefixCls), genCircleButtonStyle(token)), (0, _defineProperty2["default"])({}, "".concat(componentCls).concat(componentCls, "-round").concat(sizePrefixCls), genRoundButtonStyle(token))];
};

var genSizeBaseButtonStyle = function genSizeBaseButtonStyle(token) {
  return genSizeButtonStyle(token);
};

var genSizeSmallButtonStyle = function genSizeSmallButtonStyle(token) {
  var largeToken = (0, _theme.mergeToken)(token, {
    controlHeight: token.controlHeightSM,
    padding: token.paddingXS
  });
  return genSizeButtonStyle(largeToken, "".concat(token.componentCls, "-sm"));
};

var genSizeLargeButtonStyle = function genSizeLargeButtonStyle(token) {
  var largeToken = (0, _theme.mergeToken)(token, {
    controlHeight: token.controlHeightLG,
    fontSize: token.fontSizeLG
  });
  return genSizeButtonStyle(largeToken, "".concat(token.componentCls, "-lg"));
}; // ============================== Export ==============================


var _default = (0, _theme.genComponentStyleHook)('Button', function (token) {
  var buttonColorBgTextHover = token.buttonColorBgTextHover,
      buttonColorBgTextActive = token.buttonColorBgTextActive,
      controlTmpOutline = token.controlTmpOutline;
  var buttonToken = (0, _theme.mergeToken)(token, {
    colorBgTextHover: buttonColorBgTextHover,
    colorBgTextActive: buttonColorBgTextActive,
    colorOutlineDefault: controlTmpOutline
  });
  return [// Shared
  genSharedButtonStyle(buttonToken), // Size
  genSizeSmallButtonStyle(buttonToken), genSizeBaseButtonStyle(buttonToken), genSizeLargeButtonStyle(buttonToken), // Group (type, ghost, danger, disabled, loading)
  genTypeButtonStyle(buttonToken), // Button Group
  (0, _group["default"])(buttonToken)];
});

exports["default"] = _default;