"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault")["default"];

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _extends4 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _theme = require("../../theme");

// ============================== Styles ==============================
// ============================== Head ==============================
var genCardHeadStyle = function genCardHeadStyle(token) {
  var antCls = token.antCls,
      componentCls = token.componentCls,
      cardHeadHeight = token.cardHeadHeight,
      cardHeadPadding = token.cardHeadPadding,
      cardPaddingBase = token.cardPaddingBase,
      cardHeadTabsMarginBottom = token.cardHeadTabsMarginBottom;
  return (0, _extends4["default"])((0, _extends4["default"])({
    minHeight: cardHeadHeight,
    marginBottom: -1,
    padding: "0 ".concat(cardPaddingBase, "px"),
    color: token.colorTextHeading,
    fontWeight: token.fontWeightStrong,
    fontSize: token.fontSizeLG,
    background: 'transparent',
    borderBottom: "".concat(token.controlLineWidth, "px ").concat(token.controlLineType, " ").concat(token.colorBorderSecondary),
    borderRadius: "".concat(token.radiusBase, "px ").concat(token.radiusBase, "px 0 0")
  }, (0, _theme.clearFix)()), (0, _defineProperty2["default"])({
    '&-wrapper': {
      display: 'flex',
      alignItems: 'center'
    },
    '&-title': (0, _defineProperty2["default"])({
      display: 'inline-block',
      flex: 1,
      padding: "".concat(cardHeadPadding, "px 0"),
      overflow: 'hidden',
      whiteSpace: 'nowrap',
      textOverflow: 'ellipsis'
    }, "\n          > ".concat(componentCls, "-typography,\n          > ").concat(componentCls, "-typography-edit-content\n        "), {
      insetInlineStart: 0,
      marginTop: 0,
      marginBottom: 0
    })
  }, "".concat(antCls, "-tabs-top"), {
    clear: 'both',
    marginBottom: cardHeadTabsMarginBottom,
    color: token.colorText,
    fontWeight: 'normal',
    fontSize: token.fontSizeBase,
    '&-bar': {
      borderBottom: "".concat(token.controlLineWidth, "px ").concat(token.controlLineType, " ").concat(token.colorBorderSecondary)
    }
  }));
}; // ============================== Grid ==============================


var genCardGridStyle = function genCardGridStyle(token) {
  var cardPaddingBase = token.cardPaddingBase,
      colorBorderSecondary = token.colorBorderSecondary,
      cardShadow = token.cardShadow,
      lineWidth = token.lineWidth;
  return {
    width: '33.33%',
    padding: cardPaddingBase,
    border: 0,
    borderRadius: 0,
    boxShadow: "\n      ".concat(lineWidth, "px 0 0 0 ").concat(colorBorderSecondary, ",\n      0 ").concat(lineWidth, "px 0 0 ").concat(colorBorderSecondary, ",\n      ").concat(lineWidth, "px ").concat(lineWidth, "px 0 0 ").concat(colorBorderSecondary, ",\n      ").concat(lineWidth, "px 0 0 0 ").concat(colorBorderSecondary, " inset,\n      0 ").concat(lineWidth, "px 0 0 ").concat(colorBorderSecondary, " inset;\n    "),
    transition: "all ".concat(token.motionDurationSlow),
    '&-hoverable:hover': {
      position: 'relative',
      zIndex: 1,
      boxShadow: cardShadow
    }
  };
}; // ============================== Actions ==============================


var genCardActionsStyle = function genCardActionsStyle(token) {
  var _span;

  var componentCls = token.componentCls,
      iconCls = token.iconCls,
      cardActionsLiMargin = token.cardActionsLiMargin,
      cardActionsIconSize = token.cardActionsIconSize,
      colorBorderSecondary = token.colorBorderSecondary;
  return (0, _extends4["default"])((0, _extends4["default"])({
    margin: 0,
    padding: 0,
    listStyle: 'none',
    background: token.colorBgContainer,
    borderTop: "".concat(token.controlLineWidth, "px ").concat(token.controlLineType, " ").concat(colorBorderSecondary),
    display: 'flex'
  }, (0, _theme.clearFix)()), {
    '& > li': {
      margin: cardActionsLiMargin,
      color: token.colorTextSecondary,
      textAlign: 'center',
      '> span': (_span = {
        position: 'relative',
        display: 'block',
        minWidth: token.cardActionsIconSize * 2,
        fontSize: token.fontSize,
        lineHeight: token.lineHeight,
        cursor: 'pointer',
        '&:hover': {
          color: token.colorPrimary,
          transition: "color ".concat(token.motionDurationSlow)
        }
      }, (0, _defineProperty2["default"])(_span, "a:not(".concat(componentCls, "-btn), > ").concat(iconCls), {
        display: 'inline-block',
        width: '100%',
        color: token.colorTextSecondary,
        lineHeight: "".concat(token.fontSize * token.lineHeight, "px"),
        transition: "color ".concat(token.motionDurationSlow),
        '&:hover': {
          color: token.colorPrimary
        }
      }), (0, _defineProperty2["default"])(_span, "> ".concat(iconCls), {
        fontSize: cardActionsIconSize,
        lineHeight: "".concat(cardActionsIconSize * token.lineHeight, "px")
      }), _span),
      '&:not(:last-child)': {
        borderInlineEnd: "".concat(token.controlLineWidth, "px ").concat(token.controlLineType, " ").concat(colorBorderSecondary)
      }
    }
  });
}; // ============================== Meta ==============================


var genCardMetaStyle = function genCardMetaStyle(token) {
  return (0, _extends4["default"])((0, _extends4["default"])({
    margin: "-".concat(token.marginXXS, "px 0"),
    display: 'flex'
  }, (0, _theme.clearFix)()), {
    '&-avatar': {
      paddingInlineEnd: token.padding
    },
    '&-detail': {
      overflow: 'hidden',
      '> div:not(:last-child)': {
        marginBottom: token.marginXS
      }
    },
    '&-title': {
      overflow: 'hidden',
      color: token.colorTextHeading,
      fontWeight: token.fontWeightStrong,
      fontSize: token.fontSizeLG,
      whiteSpace: 'nowrap',
      textOverflow: 'ellipsis'
    },
    '&-description': {
      color: token.colorTextSecondary
    }
  });
}; // ============================== Inner ==============================


var genCardTypeInnerStyle = function genCardTypeInnerStyle(token) {
  var _ref;

  var componentCls = token.componentCls,
      cardPaddingBase = token.cardPaddingBase,
      colorBgContainerSecondary = token.colorBgContainerSecondary,
      cardInnerHeadPadding = token.cardInnerHeadPadding;
  return _ref = {}, (0, _defineProperty2["default"])(_ref, "".concat(componentCls, "-head"), {
    padding: "0 ".concat(cardPaddingBase, "px"),
    background: colorBgContainerSecondary,
    '&-title': {
      padding: "".concat(cardInnerHeadPadding, "px 0"),
      fontSize: token.fontSizeBase
    }
  }), (0, _defineProperty2["default"])(_ref, "".concat(componentCls, "-body"), {
    padding: "".concat(token.padding, "px ").concat(cardPaddingBase, "px")
  }), (0, _defineProperty2["default"])(_ref, "".concat(componentCls, "-extra"), {
    padding: "".concat(cardInnerHeadPadding + 1.5, "px 0")
  }), _ref;
}; // ============================== Loading ==============================


var genCardLoadingStyle = function genCardLoadingStyle(token) {
  var componentCls = token.componentCls;
  return (0, _defineProperty2["default"])({
    overflow: 'hidden'
  }, "".concat(componentCls, "-body"), {
    userSelect: 'none'
  });
}; // ============================== Basic ==============================


var genCardStyle = function genCardStyle(token) {
  var _extends3, _$concat2, _$concat3, _ref3;

  var componentCls = token.componentCls,
      cardShadow = token.cardShadow,
      cardHeadHeight = token.cardHeadHeight,
      cardHeadPadding = token.cardHeadPadding,
      cardPaddingBase = token.cardPaddingBase,
      colorBorderSecondary = token.colorBorderSecondary;
  return _ref3 = {}, (0, _defineProperty2["default"])(_ref3, componentCls, (0, _extends4["default"])((0, _extends4["default"])({}, (0, _theme.resetComponent)(token)), (_extends3 = {
    position: 'relative',
    background: token.colorBgContainer,
    borderRadius: token.radiusBase
  }, (0, _defineProperty2["default"])(_extends3, "".concat(componentCls, "-head"), genCardHeadStyle(token)), (0, _defineProperty2["default"])(_extends3, "".concat(componentCls, "-extra"), {
    // https://stackoverflow.com/a/22429853/3040605
    marginInlineStart: 'auto',
    padding: '',
    color: '',
    fontWeight: 'normal',
    fontSize: token.fontSizeBase
  }), (0, _defineProperty2["default"])(_extends3, "".concat(componentCls, "-body"), (0, _extends4["default"])({
    padding: cardPaddingBase
  }, (0, _theme.clearFix)())), (0, _defineProperty2["default"])(_extends3, "".concat(componentCls, "-grid"), genCardGridStyle(token)), (0, _defineProperty2["default"])(_extends3, "".concat(componentCls, "-cover"), {
    '> *': {
      display: 'block',
      width: '100%'
    },
    img: {
      borderRadius: "".concat(token.radiusBase, "px ").concat(token.radiusBase, "px 0 0")
    }
  }), (0, _defineProperty2["default"])(_extends3, "".concat(componentCls, "-actions"), genCardActionsStyle(token)), (0, _defineProperty2["default"])(_extends3, "".concat(componentCls, "-meta"), genCardMetaStyle(token)), _extends3))), (0, _defineProperty2["default"])(_ref3, "".concat(componentCls, "-bordered"), (0, _defineProperty2["default"])({
    border: "".concat(token.controlLineWidth, "px ").concat(token.controlLineType, " ").concat(colorBorderSecondary)
  }, "".concat(componentCls, "-cover"), {
    marginTop: -1,
    marginInlineStart: -1,
    marginInlineEnd: -1
  })), (0, _defineProperty2["default"])(_ref3, "".concat(componentCls, "-hoverable"), {
    cursor: 'pointer',
    transition: "box-shadow ".concat(token.motionDurationSlow, ", border-color ").concat(token.motionDurationSlow),
    '&:hover': {
      borderColor: 'transparent',
      boxShadow: cardShadow
    }
  }), (0, _defineProperty2["default"])(_ref3, "".concat(componentCls, "-contain-grid"), (_$concat2 = {}, (0, _defineProperty2["default"])(_$concat2, "".concat(componentCls, "-body"), {
    display: 'flex',
    flexWrap: 'wrap'
  }), (0, _defineProperty2["default"])(_$concat2, "&:not(".concat(componentCls, "-loading) ").concat(componentCls, "-body"), {
    marginBlockStart: -token.lineWidth,
    marginInlineStart: -token.lineWidth,
    padding: 0
  }), _$concat2)), (0, _defineProperty2["default"])(_ref3, "".concat(componentCls, "-contain-tabs"), (0, _defineProperty2["default"])({}, "> ".concat(componentCls, "-head"), (_$concat3 = {}, (0, _defineProperty2["default"])(_$concat3, "".concat(componentCls, "-head-title"), {
    minHeight: cardHeadHeight - cardHeadPadding,
    paddingBottom: 0
  }), (0, _defineProperty2["default"])(_$concat3, "".concat(componentCls, "-extra"), {
    paddingBottom: 0
  }), _$concat3))), (0, _defineProperty2["default"])(_ref3, "".concat(componentCls, "-type-inner"), genCardTypeInnerStyle(token)), (0, _defineProperty2["default"])(_ref3, "".concat(componentCls, "-loading"), genCardLoadingStyle(token)), (0, _defineProperty2["default"])(_ref3, "".concat(componentCls, "-rtl"), {
    direction: 'rtl'
  }), _ref3;
}; // ============================== Size ==============================


var genCardSizeStyle = function genCardSizeStyle(token) {
  var _$concat5, _$concat7;

  var componentCls = token.componentCls,
      cardPaddingBase = token.cardPaddingBase,
      cardHeadPadding = token.cardHeadPadding;
  var cardPaddingBaseSM = cardPaddingBase / 2;
  var cardHeadPaddingSM = cardHeadPadding / 2;
  return (0, _defineProperty2["default"])({}, "".concat(componentCls, "-small"), (_$concat7 = {}, (0, _defineProperty2["default"])(_$concat7, "> ".concat(componentCls, "-head"), (0, _defineProperty2["default"])({
    minHeight: cardHeadPaddingSM * 2 + token.fontSize,
    padding: "0 ".concat(cardPaddingBaseSM, "px"),
    fontSize: token.fontSize
  }, "> ".concat(componentCls, "-head-wrapper"), (_$concat5 = {}, (0, _defineProperty2["default"])(_$concat5, "> ".concat(componentCls, "-head-title"), {
    padding: "".concat(cardHeadPaddingSM, "px 0")
  }), (0, _defineProperty2["default"])(_$concat5, "> ".concat(componentCls, "-extra"), {
    padding: "".concat(cardHeadPaddingSM, "px 0"),
    fontSize: token.fontSize
  }), _$concat5))), (0, _defineProperty2["default"])(_$concat7, "> ".concat(componentCls, "-body"), {
    padding: cardPaddingBaseSM
  }), _$concat7));
}; // ============================== Export ==============================


var _default = (0, _theme.genComponentStyleHook)('Card', function (token) {
  var cardHeadPadding = token.padding;
  var cardToken = (0, _theme.mergeToken)(token, {
    cardShadow: token.boxShadowCard,
    cardHeadHeight: token.fontSizeLG + cardHeadPadding * 2,
    cardHeadPadding: cardHeadPadding,
    cardPaddingBase: token.paddingLG,
    cardHeadTabsMarginBottom: -token.padding - token.lineWidth,
    cardInnerHeadPadding: token.paddingSM,
    cardActionsLiMargin: "".concat(token.paddingSM, "px 0"),
    cardActionsIconSize: token.fontSize
  });
  return [// Style
  genCardStyle(cardToken), // Size
  genCardSizeStyle(cardToken)];
});

exports["default"] = _default;