"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault")["default"];

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _extends4 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _tinycolor = require("@ctrl/tinycolor");

var _theme = require("../../theme");

// =============================== Base ===============================
var genBaseStyle = function genBaseStyle(token) {
  var _$concat, _hover, _disabled, _extends2;

  var componentCls = token.componentCls,
      controlSize = token.controlSize,
      dotSize = token.dotSize,
      marginFull = token.marginFull,
      marginPart = token.marginPart,
      colorBgContentHover = token.colorBgContentHover,
      antCls = token.antCls;
  return (0, _defineProperty2["default"])({}, componentCls, (0, _extends4["default"])((0, _extends4["default"])({}, (0, _theme.resetComponent)(token)), (_extends2 = {
    position: 'relative',
    height: controlSize,
    margin: "".concat(marginPart, "px ").concat(marginFull, "px"),
    padding: 0,
    cursor: 'pointer',
    touchAction: 'none'
  }, (0, _defineProperty2["default"])(_extends2, "&-vertical", {
    margin: "".concat(marginFull, "px ").concat(marginPart, "px")
  }), (0, _defineProperty2["default"])(_extends2, "".concat(componentCls, "-rail"), {
    position: 'absolute',
    backgroundColor: token.colorBgContent,
    borderRadius: token.controlRadius,
    transition: "background-color ".concat(token.motionDurationSlow)
  }), (0, _defineProperty2["default"])(_extends2, "".concat(componentCls, "-track"), {
    position: 'absolute',
    backgroundColor: token.colorPrimaryBorder,
    borderRadius: token.controlRadius,
    transition: "background-color ".concat(token.motionDurationSlow)
  }), (0, _defineProperty2["default"])(_extends2, "".concat(componentCls, "-handle"), (_$concat = {
    position: 'absolute',
    width: token.handleSize,
    height: token.handleSize,
    backgroundColor: token.colorBgContainer,
    border: "".concat(token.lineHandleWidth, "px solid ").concat(token.colorPrimaryBorder),
    borderRadius: '50%',
    boxShadow: 'none',
    cursor: 'pointer',
    transition: "\n          border-color ".concat(token.motionDurationSlow, ",\n          box-shadow ").concat(token.motionDurationSlow, ",\n          transform ").concat(token.motionDurationSlow, " cubic-bezier(0.18, 0.89, 0.32, 1.28)\n        "),
    outline: 'none'
  }, (0, _defineProperty2["default"])(_$concat, "".concat(componentCls, "-dragging"), {
    zIndex: 1
  }), (0, _defineProperty2["default"])(_$concat, '&:focus', {
    borderColor: token.colorPrimaryHover,
    outline: 'none',
    boxShadow: token.handleFocusShadow
  }), _$concat)), (0, _defineProperty2["default"])(_extends2, '&:hover', (_hover = {}, (0, _defineProperty2["default"])(_hover, "".concat(componentCls, "-rail"), {
    backgroundColor: colorBgContentHover
  }), (0, _defineProperty2["default"])(_hover, "".concat(componentCls, "-track"), {
    backgroundColor: token.colorPrimaryBorderHover
  }), (0, _defineProperty2["default"])(_hover, "".concat(componentCls, "-dot"), {
    borderColor: colorBgContentHover
  }), (0, _defineProperty2["default"])(_hover, "".concat(componentCls, "-handle").concat(antCls, "-tooltip-open"), {
    borderColor: token.colorPrimary
  }), (0, _defineProperty2["default"])(_hover, "\n          ".concat(componentCls, "-handle,\n          ").concat(componentCls, "-dot-active\n        "), {
    borderColor: token.colorPrimaryHover
  }), _hover)), (0, _defineProperty2["default"])(_extends2, "".concat(componentCls, "-mark"), {
    position: 'absolute',
    fontSize: token.fontSize
  }), (0, _defineProperty2["default"])(_extends2, "".concat(componentCls, "-mark-text"), {
    position: 'absolute',
    display: 'inline-block',
    color: token.colorTextSecondary,
    textAlign: 'center',
    wordBreak: 'keep-all',
    cursor: 'pointer',
    userSelect: 'none',
    '&-active': {
      color: token.colorText
    }
  }), (0, _defineProperty2["default"])(_extends2, "".concat(componentCls, "-step"), {
    position: 'absolute',
    background: 'transparent',
    pointerEvents: 'none'
  }), (0, _defineProperty2["default"])(_extends2, "".concat(componentCls, "-dot"), {
    position: 'absolute',
    width: dotSize,
    height: dotSize,
    backgroundColor: token.colorBgContainer,
    border: "".concat(token.lineHandleWidth, "px solid ").concat(token.colorSplit),
    borderRadius: '50%',
    cursor: 'pointer',
    transition: "border-color ".concat(token.motionDurationSlow),
    '&-active': {
      borderColor: token.colorPrimaryBorder
    }
  }), (0, _defineProperty2["default"])(_extends2, '&-disabled', (_disabled = {
    cursor: 'not-allowed'
  }, (0, _defineProperty2["default"])(_disabled, "".concat(componentCls, "-rail"), {
    backgroundColor: "".concat(token.colorBgContent, " !important")
  }), (0, _defineProperty2["default"])(_disabled, "".concat(componentCls, "-track"), {
    backgroundColor: "".concat(token.colorTextDisabled, " !important")
  }), (0, _defineProperty2["default"])(_disabled, "\n          ".concat(componentCls, "-handle,\n          ").concat(componentCls, "-dot\n        "), {
    backgroundColor: token.colorBgContainer,
    borderColor: "".concat(token.colorTextDisabled, " !important"),
    boxShadow: 'none',
    cursor: 'not-allowed'
  }), (0, _defineProperty2["default"])(_disabled, "\n          ".concat(componentCls, "-mark-text,\n          ").concat(componentCls, "-dot\n        "), {
    cursor: "not-allowed !important"
  }), _disabled)), _extends2)));
}; // ============================ Horizontal ============================


var genDirectionStyle = function genDirectionStyle(token, horizontal) {
  var _$concat2, _$concat5, _$concat6, _ref2;

  var componentCls = token.componentCls,
      railSize = token.railSize,
      controlSize = token.controlSize,
      handleSize = token.handleSize,
      dotSize = token.dotSize;
  var railPadding = horizontal ? 'paddingBlock' : 'paddingInline';
  var full = horizontal ? 'width' : 'height';
  var part = horizontal ? 'height' : 'width';
  var handlePos = horizontal ? 'insetBlockStart' : 'insetInlineStart';
  var markInset = horizontal ? 'top' : 'insetInlineStart';
  return _ref2 = {}, (0, _defineProperty2["default"])(_ref2, railPadding, railSize), (0, _defineProperty2["default"])(_ref2, part, controlSize), (0, _defineProperty2["default"])(_ref2, "".concat(componentCls, "-rail"), (_$concat2 = {}, (0, _defineProperty2["default"])(_$concat2, full, '100%'), (0, _defineProperty2["default"])(_$concat2, part, railSize), _$concat2)), (0, _defineProperty2["default"])(_ref2, "".concat(componentCls, "-track"), (0, _defineProperty2["default"])({}, part, railSize)), (0, _defineProperty2["default"])(_ref2, "".concat(componentCls, "-handle"), (0, _defineProperty2["default"])({}, handlePos, (controlSize - handleSize) / 2)), (0, _defineProperty2["default"])(_ref2, "".concat(componentCls, "-mark"), (_$concat5 = {
    // Reset all
    insetInlineStart: 0,
    top: 0
  }, (0, _defineProperty2["default"])(_$concat5, markInset, handleSize), (0, _defineProperty2["default"])(_$concat5, full, '100%'), _$concat5)), (0, _defineProperty2["default"])(_ref2, "".concat(componentCls, "-step"), (_$concat6 = {
    // Reset all
    insetInlineStart: 0,
    top: 0
  }, (0, _defineProperty2["default"])(_$concat6, markInset, railSize), (0, _defineProperty2["default"])(_$concat6, full, '100%'), (0, _defineProperty2["default"])(_$concat6, part, railSize), _$concat6)), (0, _defineProperty2["default"])(_ref2, "".concat(componentCls, "-dot"), (0, _defineProperty2["default"])({
    position: 'absolute'
  }, handlePos, (railSize - dotSize) / 2)), _ref2;
}; // ============================ Horizontal ============================


var genHorizontalStyle = function genHorizontalStyle(token) {
  var componentCls = token.componentCls,
      marginPartWithMark = token.marginPartWithMark;
  return (0, _defineProperty2["default"])({}, "".concat(componentCls, "-horizontal"), (0, _extends4["default"])((0, _extends4["default"])({}, genDirectionStyle(token, true)), (0, _defineProperty2["default"])({}, "&".concat(componentCls, "-with-marks"), {
    marginBottom: marginPartWithMark
  })));
}; // ============================= Vertical =============================


var genVerticalStyle = function genVerticalStyle(token) {
  var componentCls = token.componentCls;
  return (0, _defineProperty2["default"])({}, "".concat(componentCls, "-vertical"), (0, _extends4["default"])((0, _extends4["default"])({}, genDirectionStyle(token, false)), {
    height: '100%'
  }));
}; // ============================== Export ==============================


var _default = (0, _theme.genComponentStyleHook)('Slider', function (token) {
  var sliderToken = (0, _theme.mergeToken)(token, {
    marginPart: (token.controlHeight - token.controlSize) / 2,
    marginFull: token.controlSize / 2,
    marginPartWithMark: token.controlHeightLG - token.controlSize,
    handleFocusShadow: "0 0 0 5px ".concat(new _tinycolor.TinyColor(token.colorPrimary).setAlpha(0.12).toRgbString())
  });
  return [genBaseStyle(sliderToken), genHorizontalStyle(sliderToken), genVerticalStyle(sliderToken)];
}, function (token) {
  // Handle line width is always width-er 1px
  var increaseHandleWidth = 1;
  var controlSize = token.controlHeightSM / 2;
  var lineHandleWidth = token.lineWidth + increaseHandleWidth;
  return {
    controlSize: controlSize,
    railSize: controlSize / 3,
    handleSize: controlSize + lineHandleWidth,
    dotSize: controlSize / 3 * 2,
    lineHandleWidth: lineHandleWidth
  };
});

exports["default"] = _default;